@@ -1,5 +1,3 @@
-package org.apache.maven.shared.dependency.graph;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.dependency.graph;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,10 +16,12 @@ package org.apache.maven.shared.dependency.graph;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.dependency.graph;
 
 import java.util.List;
 
 import org.apache.maven.artifact.Artifact;
+import org.apache.maven.model.Exclusion;
 import org.apache.maven.shared.dependency.graph.traversal.DependencyNodeVisitor;
 
 /**
@@ -31,8 +31,7 @@ import org.apache.maven.shared.dependency.graph.traversal.DependencyNodeVisitor;
  * @author Hervé Boutemy
  * @since 2.0
  */
-public interface DependencyNode
-{
+public interface DependencyNode {
     /**
      * @return Artifact for this DependencyNode.
      */
@@ -45,30 +44,30 @@ public interface DependencyNode
 
     /**
      * Applies the specified dependency node visitor to this dependency node and its children.
-     * 
+     *
      * @param visitor the dependency node visitor to use
      * @return the visitor result of ending the visit to this node
      * @since 1.1
      */
-    boolean accept( DependencyNodeVisitor visitor );
+    boolean accept(DependencyNodeVisitor visitor);
 
     /**
      * Gets the parent dependency node of this dependency node.
-     * 
+     *
      * @return the parent dependency node
      */
     DependencyNode getParent();
 
     /**
      * Gets the version or version range for the dependency before dependency management was applied (if any).
-     * 
+     *
      * @return The dependency version before dependency management or {@code null} if the version was not managed.
      */
     String getPremanagedVersion();
 
     /**
      * Gets the scope for the dependency before dependency management was applied (if any).
-     * 
+     *
      * @return The dependency scope before dependency management or {@code null} if the scope was not managed.
      */
     String getPremanagedScope();
@@ -76,14 +75,14 @@ public interface DependencyNode
     /**
      * A constraint on versions for a dependency. A constraint can either consist of one or more version ranges or a
      * single version.
-     * 
+     *
      * @return The constraint on the dependency.
      */
     String getVersionConstraint();
 
     /**
      * Returns a string representation of this dependency node.
-     * 
+     *
      * @return the string representation
      */
     String toNodeString();
@@ -92,4 +91,10 @@ public interface DependencyNode
      * @return true for an optional dependency.
      */
     Boolean getOptional();
+
+    /**
+     *
+     * @return the exclusions of the dependency
+     */
+    List<Exclusion> getExclusions();
 }
