@@ -1,5 +1,3 @@
-package org.apache.maven.shared.dependency.graph.filter;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.dependency.graph.filter;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.dependency.graph.filter;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.dependency.graph.filter;
 
 import java.util.Collections;
 import java.util.List;
@@ -26,14 +25,12 @@ import org.apache.maven.shared.dependency.graph.DependencyNode;
 
 /**
  * A dependency node filter than only accepts nodes that are ancestors of, or equal to, a given list of nodes.
- * 
+ *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id: AncestorOrSelfDependencyNodeFilter.java 1684260 2015-06-08 19:57:54Z rfscholte $
+ * @version $Id$
  * @since 1.1
  */
-public class AncestorOrSelfDependencyNodeFilter
-    implements DependencyNodeFilter
-{
+public class AncestorOrSelfDependencyNodeFilter implements DependencyNodeFilter {
     // fields -----------------------------------------------------------------
 
     /**
@@ -43,19 +40,17 @@ public class AncestorOrSelfDependencyNodeFilter
 
     // constructors -----------------------------------------------------------
 
-    public AncestorOrSelfDependencyNodeFilter( DependencyNode descendantNode )
-    {
-        this( Collections.singletonList( descendantNode ) );
+    public AncestorOrSelfDependencyNodeFilter(DependencyNode descendantNode) {
+        this(Collections.singletonList(descendantNode));
     }
 
     /**
      * Creates a dependency node filter that only accepts nodes that are ancestors of, or equal to, the specified list
      * of nodes.
-     * 
+     *
      * @param descendantNodes the list of nodes to accept ancestors-or-self of
      */
-    public AncestorOrSelfDependencyNodeFilter( List<DependencyNode> descendantNodes )
-    {
+    public AncestorOrSelfDependencyNodeFilter(List<DependencyNode> descendantNodes) {
         this.descendantNodes = descendantNodes;
     }
 
@@ -65,12 +60,9 @@ public class AncestorOrSelfDependencyNodeFilter
      * {@inheritDoc}
      */
     @Override
-    public boolean accept( DependencyNode node )
-    {
-        for ( DependencyNode descendantNode : descendantNodes )
-        {
-            if ( isAncestorOrSelf( node, descendantNode ) )
-            {
+    public boolean accept(DependencyNode node) {
+        for (DependencyNode descendantNode : descendantNodes) {
+            if (isAncestorOrSelf(node, descendantNode)) {
                 return true;
             }
         }
@@ -82,18 +74,16 @@ public class AncestorOrSelfDependencyNodeFilter
 
     /**
      * Gets whether the first dependency node is an ancestor-or-self of the second.
-     * 
+     *
      * @param ancestorNode the ancestor-or-self dependency node
      * @param descendantNode the dependency node to test
      * @return <code>true</code> if <code>ancestorNode</code> is an ancestor, or equal to, <code>descendantNode</code>
      */
-    private boolean isAncestorOrSelf( DependencyNode ancestorNode, DependencyNode descendantNode )
-    {
+    private boolean isAncestorOrSelf(DependencyNode ancestorNode, DependencyNode descendantNode) {
         boolean ancestor = false;
 
-        while ( !ancestor && descendantNode != null )
-        {
-            ancestor = ancestorNode.equals( descendantNode );
+        while (!ancestor && descendantNode != null) {
+            ancestor = ancestorNode.equals(descendantNode);
 
             descendantNode = descendantNode.getParent();
         }
